@@ -332,6 +332,24 @@ def resolve_references(obj):
     elif isinstance(obj, list):
         # Process each item in a list recursively
         return [resolve_references(item) for item in obj]
+    elif isinstance(obj, str) and obj.startswith("<function ") and "at 0x" in obj:
+        # Handle function references that got converted to strings
+        print(f"[REFERENCE_DEBUG] Detected string representation of function: {obj}")
+        try:
+            # Try to import common functions from the main module
+            from __main__ import multiprocessing_func, partial_func
+            # Check if the function name is in the string representation
+            function_name = obj.split()[1]
+            if "multiprocessing_func" in function_name:
+                print("[REFERENCE_DEBUG] Resolved to multiprocessing_func")
+                return multiprocessing_func
+            elif "partial_func" in function_name or "partial" in function_name:
+                print("[REFERENCE_DEBUG] Resolved to partial_func")
+                return partial_func
+            else:
+                print(f"[REFERENCE_DEBUG] Could not match function name: {function_name}")
+        except Exception as e:
+            print(f"[REFERENCE_DEBUG] Error resolving function reference: {e}")
     
     # Return non-dict, non-list objects as is
     return obj
