@@ -264,4 +264,53 @@ def is_large_data(data_to_upload, threshold_mb=10):
     else:
         # If we couldn't measure the size by any method, treat as large to be safe
         debug_print("Could not determine size by any method, treating as large for safety")
-        return True
\ No newline at end of file
+        return True
+
+def get_data_size_mb(data):
+    """
+    Get the size of data in megabytes
+    
+    Args:
+        data: The data to measure
+        
+    Returns:
+        float: Size in MB
+    """
+    try:
+        # For simple types, use sys.getsizeof
+        if isinstance(data, (int, float, str, bool, type(None))):
+            return sys.getsizeof(data) / (1024 * 1024)
+            
+        # For bytes, use len
+        if isinstance(data, bytes):
+            return len(data) / (1024 * 1024)
+            
+        # Try numpy arrays first (common in astronomy)
+        try:
+            import numpy as np
+            if isinstance(data, np.ndarray):
+                return data.nbytes / (1024 * 1024)
+        except ImportError:
+            pass
+            
+        # For pandas DataFrames
+        try:
+            import pandas as pd
+            if isinstance(data, (pd.DataFrame, pd.Series)):
+                return data.memory_usage(deep=True).sum() / (1024 * 1024)
+        except ImportError:
+            pass
+            
+        # For dictionaries and lists, try JSON first (usually smaller than pickle)
+        if isinstance(data, (dict, list)):
+            try:
+                json_size = len(json.dumps(data).encode()) / (1024 * 1024)
+                return json_size
+            except:
+                pass
+                
+        # Default to pickle
+        return len(pickle.dumps(data)) / (1024 * 1024)
+    except Exception as e:
+        # If all else fails, return a conservative estimate
+        return 10  # Assume 10MB as default
\ No newline at end of file
